@@ -22,10 +22,4 @@ class PysFileBuffer(PysBuffer):
             self.name = '<string>' if name is None else to_str(name)
 
     def __repr__(self):
-        return '<FileBuffer from {!r}>'.format(self.name)
-
-class PysCode(PysBuffer):
-
-    def __init__(self, **kwargs):
-        for key, value in kwargs.items():
-            setattr(self, key, value)
\ No newline at end of file
+        return '<FileBuffer from {!r}>'.format(self.name)
\ No newline at end of file
