@@ -1,7 +1,9 @@
 from .cache import hook
 from .exceptions import PysException, PysShouldReturn
-from .objects import PysChainFunction, PysFunction
-from .utils import is_object_of
+from .objects import PysPythonFunction, PysFunction
+from .position import PysPosition
+from .results import PysRunTimeResult
+from .utils import is_object_of, print_traceback
 
 from contextlib import contextmanager
 from types import MethodType
@@ -21,28 +23,22 @@ def handle_call(object, context, position, flags):
         object.__code__.position = position
         object.__code__.flags = flags
 
-    elif isinstance(object, PysChainFunction):
+    elif isinstance(object, PysPythonFunction):
         object.__code__.context = context
         object.__code__.position = position
         object.__code__.flags = flags
 
-    elif isinstance(object, MethodType) and isinstance(object.__func__, PysFunction):
-        object.__func__.__code__.call_context = context
-        object.__func__.__code__.position = position
-        object.__func__.__code__.flags = flags
-
     elif isinstance(object, type):
+        for call in ('__new__', '__init__'):
+            handle_call(getattr(object, call, None), context, position, flags)
 
-        for call in ('__init__', '__new__'):
-            fn = getattr(object, call, None)
-
-            if isinstance(fn, PysFunction):
-                fn.__code__.call_context = context
-                fn.__code__.position = position
-                fn.__code__.flags = flags
+    elif isinstance(object, MethodType):
+        handle_call(object.__func__, context, position, flags)
 
 def handle_execute(result):
-    try:
+    result_runtime = PysRunTimeResult()
+
+    with handle_exception(result_runtime, result.context, PysPosition(result.context.file, 0, 0)):
 
         if result.error:
             if is_object_of(result.error.exception, SystemExit):
@@ -51,10 +47,15 @@ def handle_execute(result):
                 hook.exception(result.error)
             return 1
 
-        elif len(result.result) == 1 and hook.display is not None:
-            hook.display(result.result[0])
+        elif hook.display is not None:
+            if result.mode == 'exec' and len(result.value) == 1:
+                hook.display(result.value[0])
+            elif result.mode == 'eval':
+                hook.display(result.value)
 
-    except:
+    if result_runtime.should_return():
+        if result_runtime.error:
+            print_traceback(result_runtime.error)
         return 1
 
     return 0
\ No newline at end of file
